@@ -51,17 +51,15 @@ Nothing.
 
 =cut
 
-use 5.008008;
 use strict;
 use warnings;
 use base qw(Win32::SqlServer::DTS::Assignment Class::Accessor);
 use Hash::Util qw(lock_keys);
+our $VERSION = '0.13'; # VERSION
 
 __PACKAGE__->follow_best_practice;
 __PACKAGE__->mk_ro_accessors(qw(filename section key));
 
-our $VERSION = '0.03';
-
 =head2 METHODS
 
 Inherits all methods from C<Win32::SqlServer::DTS::Assignment>.
