@@ -52,13 +52,11 @@ Nothing.
 
 =cut
 
-use 5.008008;
 use strict;
 use warnings;
 use base qw(Win32::SqlServer::DTS::Assignment Class::Accessor);
 use Hash::Util qw(lock_keys);
-
-our $VERSION = '0.03';
+our $VERSION = '0.13'; # VERSION
 
 =head2 METHODS
 
